﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Reflection;

namespace HeuristicLab.Persistence {
  [AttributeUsage(AttributeTargets.Method, AllowMultiple = false, Inherited = false)]
  public sealed class StorableConversionAttribute : Attribute {
    public uint SrcVersion { get; set; }

    public StorableConversionAttribute(uint srcVersion)
    {
      this.SrcVersion = srcVersion;
    }

    public static bool IsStorableConversionMethod(MethodInfo mi) {
      return Attribute.IsDefined(mi, typeof(StorableConversionAttribute), false);
    }
    public static StorableConversionAttribute GetTransformerAttribute(MethodInfo mi) {
      return (StorableConversionAttribute)Attribute.GetCustomAttribute(mi, typeof(StorableConversionAttribute), false);
    }
    public static uint GetVersion(MethodInfo mi) {
      return GetTransformerAttribute(mi).SrcVersion;
    }
  }
}
